<!-- prettier-ignore -->
{# source: https://github.com/pydata/pydata-sphinx-theme/blob/master/src/pydata_sphinx_theme/theme/pydata_sphinx_theme/layout.html #}
{# we use the version shortly after v0.8.1 and plan to pin to v0.8.2 #}
{# note that the original file wasn't formatted with prettier, hence, need to reformat to compare! #}
{# the two changes made concern identity snippet injection and full-screen #}

{%- extends "basic/layout.html" %} {%- import "static/webpack-macros.html" as
_webpack with context %} {%- block css %}
<link
  rel="stylesheet"
  href="//code.jquery.com/ui/1.13.1/themes/base/jquery-ui.css"
/>
<script>
  document.documentElement.dataset.mode =
    localStorage.getItem("mode") || "{{ default_mode }}";
  document.documentElement.dataset.theme =
    localStorage.getItem("theme") || "light";
</script>
{{ _webpack.head_pre_assets() }} {{ _webpack.head_pre_icons() }} {{- css() }} {{
_webpack.head_js_preload() }} {%- endblock %} {%- block extrahead %}
<meta name="viewport" content="width=device-width, initial-scale=1" />
<meta name="docsearch:language" content="{{ language }}" />
{% for favicon in theme_favicons %} {% if favicon.href[:4] == 'http'%}
<link
  rel="{{ favicon.rel }}"
  sizes="{{ favicon.sizes }}"
  href="{{ favicon.href }}"
/>
{% else %}
<link
  rel="{{ favicon.rel }}"
  sizes="{{ favicon.sizes }}"
  href="{{ pathto('_static/' + favicon.href, 1) }}"
/>
{% endif %} {% endfor %}
<script
  type="text/javascript"
  src="https://identity.netlify.com/v1/netlify-identity-widget.js"
></script>
<script>
  netlifyIdentity.on("login", () => refresh_identity());
  netlifyIdentity.on("close", () => (location.href = "/login"));
  function refresh_identity() {
    netlifyIdentity.refresh().then((jwt) => console.log(jwt));
  }
  async function refresh_repeat() {
    for (let i = 0; i < 1000; i++) {
      await new Promise((resolve) => setTimeout(resolve, 20 * 60000));
      refresh_identity();
    }
  }
  refresh_repeat();
</script>
{%- endblock %} {# Silence the sidebar's, relbar's #} {% block header %}{%
endblock %} {% block relbar1 %}{% endblock %} {% block relbar2 %}{% endblock %}
{% block sidebarsourcelink %}{% endblock %} {% block body_tag %}
<body
  data-spy="scroll"
  data-target="#bd-toc-nav"
  data-offset="60"
  data-default-mode="{{ default_mode }}"
>
  {%- endblock %} {%- block content %} {# Added to support a banner with an
  alert #}
  <div class="container-fluid" id="banner"></div>

  {% block docs_navbar %}
  <nav
    class="navbar navbar-light navbar-expand-lg bg-light fixed-top bd-navbar"
    id="navbar-main"
  >
    {%- include "docs-navbar.html" %}
  </nav>
  {% endblock %}

  <div class="container-fluid">
    <div class="row">
      {% block docs_sidebar %}
      <!-- prettier-ignore -->
      {% if sidebars %}
        {% set sidebarblock = "d-lg-block" %}
      {% else %}
        {% set sidebarblock = "d-xl-block" %}
      {% endif %}
      <div class="d-none {{ sidebarblock }} col-md-3 col-xl-2 bd-sidebar">
        <div class="sidebar-start-items">
          {%- for sidebartemplate in sidebars %} {%- include sidebartemplate %}
          {%- endfor %}
        </div>
        <div class="sidebar-end-items">
          {%- for leftsidebartemplate in theme_left_sidebar_end %} {%- include
          leftsidebartemplate %} {%- endfor %}
        </div>
      </div>
      {% endblock %} {% block docs_toc %}
      <div class="d-none d-xl-block col-xl-2 bd-toc">
        {% if meta is defined and not (meta is not none and 'notoc' in meta) %}
        {% for toc_item in theme_page_sidebar_items %}
        <div class="toc-item">{% include toc_item %}</div>
        {% endfor %} {% endif %}
      </div>
      {% endblock %} {% block docs_main %}
      <!-- prettier-ignore -->
      {% if sidebars %}
        {% set bodylgsize = "col-lg-9" %}
      {% else %}
        {% set bodylgsize = "col-lg-12" %}
      {% endif %}
      <main
        class="col-12 {{ bodylgsize }} col-xl-8 py-md-5 bd-content"
        role="main"
      >
        {% block docs_body %}
        <div>{% block body %} {% endblock %}</div>
        {% endblock %}
        <!-- prettier-ignore -->
        {% if sidebars %}
          {% include "prev-next.html" %}
        {% endif %}
      </main>
      {% endblock %}
    </div>
  </div>

  {%- block scripts_end %} {{ _webpack.body_post() }} {%- endblock %} {%-
  endblock %} {%- block footer %} {%- include "footer.html" %} {%- endblock %}
</body>
