{% if ablog %}
<ul style="list-style: none">
  {% set pcount = 1 %} {% for recent in ablog.recent(5, pagename) %}
  <li>
    <a href="{{ pathto(recent.docname) }}{{ anchor(recent) }}"
      >{{ recent.title }}</a
    >
  </li>
  {% endfor %}
</ul>
{% endif %}
