# auto-generated by lndocs
import sys
from pathlib import Path

import {{ lamin_package_name }}

HERE = Path(__file__).parent
sys.path[:0] = [str(HERE), str(HERE.parent)]
from lamin_sphinx import *  # noqa
from lamin_sphinx import html_context, html_theme_options

project = "{{ lamin_project_name }}"
html_title = "{{ lamin_project_name }} | Lamin Labs"
release = {{ lamin_package_name }}.__version__
html_context["github_repo"] = "{{ lamin_repository_name }}"  # noqa
# We're actually using this for the link behind the brand of the page!
html_theme_options["logo"] = {"link": "docs/{{ lamin_project_slug }}"}  # noqa

ogp_site_url = "https://lamin.ai/docs/{{ lamin_project_slug }}"
